SUTRA
============
.. image:: https://readthedocs.org/projects/sutra/badge/?version=latest&style=flat
                    :target: https://sutra.readthedocs.io
.. image:: https://img.shields.io/travis/KWR-Water/greta
                    :target: https://travis-ci.com/KWR-Water/sutra
.. image:: https://img.shields.io/codecov/c/gh/KWR-Water/sutra
                    :target: https://codecov.io/gh/KWR-Water/sutra

A tool to calculate the fate of Organic Micropollutant and pathogens in the subsoil.

See documentation_ for more information.


Installation
------------
To get the latest stable version, use::

    python -m pip install git+https://github.com/KWR-Water/sutra.git@main

or::

    pip install git+ssh://git@github.com/KWR-Water/sutra.git@main

License
-------

This package is MIT licensed. See `License File <https://github.com/KWR-Water/greta/blob/master/LICENSE>`__.

.. _documentation: https://greta.readthedocs.io/en/latest/
